==> jc-1.4.0.tar.gz: org/dellroad/jc/cgen/analysis/ActiveUseAnalysis.h <==
// public class org.dellroad.jc.cgen.analysis.ActiveUseAnalysis

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 575cb9ef79142a72 org_dellroad_jc_cgen_analysis_ActiveUseAnalysis
// @dep_class 36c7c662bc399f02 soot_toolkits_scalar_AbstractFlowAnalysis
// @dep_class d57b0cae040f1388 soot_toolkits_scalar_FlowAnalysis
// @dep_class 670b274dd70b8d71 soot_toolkits_scalar_ForwardFlowAnalysis

// header file dependencies
// @dep_header soot_toolkits_scalar_ForwardFlowAnalysis

#include "soot/toolkits/scalar/ForwardFlowAnalysis.h"

#ifndef _JC_org_dellroad_jc_cgen_analysis_ActiveUseAnalysis_H_
#define _JC_org_dellroad_jc_cgen_analysis_ActiveUseAnalysis_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_soot_Body$object;
struct _jc_soot_SootClass$object;
struct _jc_soot_Unit$object;
struct _jc_soot_toolkits_graph_UnitGraph$object;
struct _jc_soot_toolkits_scalar_FlowSet$object;

// Typedefs
typedef struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseAnalysis$sub_refs	_jc_org_dellroad_jc_cgen_analysis_ActiveUseAnalysis$sub_refs;
typedef struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseAnalysis$sub_nonrefs	_jc_org_dellroad_jc_cgen_analysis_ActiveUseAnalysis$sub_nonrefs;
typedef struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseAnalysis$refs	_jc_org_dellroad_jc_cgen_analysis_ActiveUseAnalysis$refs;
typedef struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseAnalysis$nonrefs	_jc_org_dellroad_jc_cgen_analysis_ActiveUseAnalysis$nonrefs;
typedef struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseAnalysis$object	_jc_org_dellroad_jc_cgen_analysis_ActiveUseAnalysis$object;

typedef const struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseAnalysis$vmethods	_jc_org_dellroad_jc_cgen_analysis_ActiveUseAnalysis$vmethods;
typedef const struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseAnalysis$vtable	_jc_org_dellroad_jc_cgen_analysis_ActiveUseAnalysis$vtable;
typedef const struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseAnalysis$vtype	_jc_org_dellroad_jc_cgen_analysis_ActiveUseAnalysis$vtype;

// Constructors
extern void _jc_org_dellroad_jc_cgen_analysis_ActiveUseAnalysis$method$_init$3a6465c484af9c25(_jc_env *, struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseAnalysis$object *, struct _jc_soot_Body$object *);
extern void _jc_org_dellroad_jc_cgen_analysis_ActiveUseAnalysis$method$_init$4a1d314cee6c2507(_jc_env *, struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseAnalysis$object *, struct _jc_soot_toolkits_graph_UnitGraph$object *);

// Virtual methods
extern void _jc_org_dellroad_jc_cgen_analysis_ActiveUseAnalysis$method$addTransitive$887aecff33247547(_jc_env *, struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseAnalysis$object *, struct _jc_object *, struct _jc_soot_SootClass$object *);
extern void _jc_org_dellroad_jc_cgen_analysis_ActiveUseAnalysis$method$copy$0585c1f937996187(_jc_env *, struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseAnalysis$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *);
extern struct _jc_java_lang_Object$object *_jc_org_dellroad_jc_cgen_analysis_ActiveUseAnalysis$method$entryInitialFlow$8b63b3b8f54d43fb(_jc_env *, struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseAnalysis$object *);
extern void _jc_org_dellroad_jc_cgen_analysis_ActiveUseAnalysis$method$flowThrough$087b926607d6a11b(_jc_env *, struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseAnalysis$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *);
extern jboolean _jc_org_dellroad_jc_cgen_analysis_ActiveUseAnalysis$method$isCheckNeeded$5e337b96839b50c8(_jc_env *, struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseAnalysis$object *, struct _jc_object *, struct _jc_soot_SootClass$object *);
extern void _jc_org_dellroad_jc_cgen_analysis_ActiveUseAnalysis$method$merge$37b91166a64cb493(_jc_env *, struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseAnalysis$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *);
extern struct _jc_java_lang_Object$object *_jc_org_dellroad_jc_cgen_analysis_ActiveUseAnalysis$method$newInitialFlow$8126aa62e2c0e28e(_jc_env *, struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseAnalysis$object *);

// Virtual method descriptors
extern _jc_method _jc_org_dellroad_jc_cgen_analysis_ActiveUseAnalysis$method_info$addTransitive$887aecff33247547;
extern _jc_method _jc_org_dellroad_jc_cgen_analysis_ActiveUseAnalysis$method_info$copy$0585c1f937996187;
extern _jc_method _jc_org_dellroad_jc_cgen_analysis_ActiveUseAnalysis$method_info$entryInitialFlow$8b63b3b8f54d43fb;
extern _jc_method _jc_org_dellroad_jc_cgen_analysis_ActiveUseAnalysis$method_info$flowThrough$087b926607d6a11b;
extern _jc_method _jc_org_dellroad_jc_cgen_analysis_ActiveUseAnalysis$method_info$isCheckNeeded$5e337b96839b50c8;
extern _jc_method _jc_org_dellroad_jc_cgen_analysis_ActiveUseAnalysis$method_info$merge$37b91166a64cb493;
extern _jc_method _jc_org_dellroad_jc_cgen_analysis_ActiveUseAnalysis$method_info$newInitialFlow$8126aa62e2c0e28e;

// Virtual methods structure
struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseAnalysis$vmethods {
	void	(*addTransitive$887aecff33247547)(_jc_env *, struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseAnalysis$object *, struct _jc_object *, struct _jc_soot_SootClass$object *);
	void	(*copy$0585c1f937996187)(_jc_env *, struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseAnalysis$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *);
	struct _jc_java_lang_Object$object	*(*entryInitialFlow$8b63b3b8f54d43fb)(_jc_env *, struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseAnalysis$object *);
	void	(*flowThrough$087b926607d6a11b)(_jc_env *, struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseAnalysis$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *);
	jboolean	(*isCheckNeeded$5e337b96839b50c8)(_jc_env *, struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseAnalysis$object *, struct _jc_object *, struct _jc_soot_SootClass$object *);
	void	(*merge$37b91166a64cb493)(_jc_env *, struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseAnalysis$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *);
	struct _jc_java_lang_Object$object	*(*newInitialFlow$8126aa62e2c0e28e)(_jc_env *, struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseAnalysis$object *);
};

// Vtable
struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseAnalysis$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_toolkits_scalar_AbstractFlowAnalysis$vmethods	soot_toolkits_scalar_AbstractFlowAnalysis;
	_jc_soot_toolkits_scalar_FlowAnalysis$vmethods	soot_toolkits_scalar_FlowAnalysis;
	_jc_soot_toolkits_scalar_ForwardFlowAnalysis$vmethods	soot_toolkits_scalar_ForwardFlowAnalysis;
	_jc_org_dellroad_jc_cgen_analysis_ActiveUseAnalysis$vmethods	org_dellroad_jc_cgen_analysis_ActiveUseAnalysis;
};

// Vtype
struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseAnalysis$vtype {
	_jc_type			type;
	_jc_org_dellroad_jc_cgen_analysis_ActiveUseAnalysis$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseAnalysis$sub_refs {
	struct _jc_soot_toolkits_graph_UnitGraph$object	*graph;
};

// Reference instance fields (object)
struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseAnalysis$refs {
    _jc_org_dellroad_jc_cgen_analysis_ActiveUseAnalysis$sub_refs	org_dellroad_jc_cgen_analysis_ActiveUseAnalysis;
    _jc_soot_toolkits_scalar_ForwardFlowAnalysis$sub_refs	soot_toolkits_scalar_ForwardFlowAnalysis;
    _jc_soot_toolkits_scalar_FlowAnalysis$sub_refs	soot_toolkits_scalar_FlowAnalysis;
    _jc_soot_toolkits_scalar_AbstractFlowAnalysis$sub_refs	soot_toolkits_scalar_AbstractFlowAnalysis;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseAnalysis$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseAnalysis$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_toolkits_scalar_AbstractFlowAnalysis$sub_nonrefs	soot_toolkits_scalar_AbstractFlowAnalysis;
    _jc_soot_toolkits_scalar_FlowAnalysis$sub_nonrefs	soot_toolkits_scalar_FlowAnalysis;
    _jc_soot_toolkits_scalar_ForwardFlowAnalysis$sub_nonrefs	soot_toolkits_scalar_ForwardFlowAnalysis;
    _jc_org_dellroad_jc_cgen_analysis_ActiveUseAnalysis$sub_nonrefs	org_dellroad_jc_cgen_analysis_ActiveUseAnalysis;
};

// Object instance structure
struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseAnalysis$object {
	_jc_org_dellroad_jc_cgen_analysis_ActiveUseAnalysis$refs	refs[0];
	_jc_word		lockword;
	_jc_org_dellroad_jc_cgen_analysis_ActiveUseAnalysis$vtype	*vtype;
	_jc_org_dellroad_jc_cgen_analysis_ActiveUseAnalysis$nonrefs	nonrefs;
};

// Type structure
extern _jc_org_dellroad_jc_cgen_analysis_ActiveUseAnalysis$vtype _jc_org_dellroad_jc_cgen_analysis_ActiveUseAnalysis$type;

// Array types class info structures
_JC_DECL_ARRAYS(org_dellroad_jc_cgen_analysis_ActiveUseAnalysis, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_org_dellroad_jc_cgen_analysis_ActiveUseAnalysis$class_object;

#endif	/* _JC_org_dellroad_jc_cgen_analysis_ActiveUseAnalysis_H_ */

==> jc-1.4.6.tar.gz: org/dellroad/jc/cgen/analysis/ActiveUseAnalysis.h <==
// public class org.dellroad.jc.cgen.analysis.ActiveUseAnalysis

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 575cb9ef79142a72 org_dellroad_jc_cgen_analysis_ActiveUseAnalysis
// @dep_class 36c7c662bc399f02 soot_toolkits_scalar_AbstractFlowAnalysis
// @dep_class d57b0cae040f1388 soot_toolkits_scalar_FlowAnalysis
// @dep_class 670b274dd70b8d71 soot_toolkits_scalar_ForwardFlowAnalysis

// header file dependencies
// @dep_header soot_toolkits_scalar_ForwardFlowAnalysis

#include "soot/toolkits/scalar/ForwardFlowAnalysis.h"

#ifndef _JC_org_dellroad_jc_cgen_analysis_ActiveUseAnalysis_H_
#define _JC_org_dellroad_jc_cgen_analysis_ActiveUseAnalysis_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_soot_Body$object;
struct _jc_soot_SootClass$object;
struct _jc_soot_Unit$object;
struct _jc_soot_toolkits_graph_UnitGraph$object;
struct _jc_soot_toolkits_scalar_FlowSet$object;

// Typedefs
typedef struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseAnalysis$sub_refs	_jc_org_dellroad_jc_cgen_analysis_ActiveUseAnalysis$sub_refs;
typedef struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseAnalysis$sub_nonrefs	_jc_org_dellroad_jc_cgen_analysis_ActiveUseAnalysis$sub_nonrefs;
typedef struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseAnalysis$refs	_jc_org_dellroad_jc_cgen_analysis_ActiveUseAnalysis$refs;
typedef struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseAnalysis$nonrefs	_jc_org_dellroad_jc_cgen_analysis_ActiveUseAnalysis$nonrefs;
typedef struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseAnalysis$object	_jc_org_dellroad_jc_cgen_analysis_ActiveUseAnalysis$object;

typedef const struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseAnalysis$vmethods	_jc_org_dellroad_jc_cgen_analysis_ActiveUseAnalysis$vmethods;
typedef const struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseAnalysis$vtable	_jc_org_dellroad_jc_cgen_analysis_ActiveUseAnalysis$vtable;
typedef const struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseAnalysis$vtype	_jc_org_dellroad_jc_cgen_analysis_ActiveUseAnalysis$vtype;

// Constructors
extern void _jc_org_dellroad_jc_cgen_analysis_ActiveUseAnalysis$method$_init$3a6465c484af9c25(_jc_env *, struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseAnalysis$object *, struct _jc_soot_Body$object *) _JC_JCNI_ATTR;
extern void _jc_org_dellroad_jc_cgen_analysis_ActiveUseAnalysis$method$_init$4a1d314cee6c2507(_jc_env *, struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseAnalysis$object *, struct _jc_soot_toolkits_graph_UnitGraph$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_org_dellroad_jc_cgen_analysis_ActiveUseAnalysis$method$addTransitive$887aecff33247547(_jc_env *, struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseAnalysis$object *, struct _jc_object *, struct _jc_soot_SootClass$object *) _JC_JCNI_ATTR;
extern void _jc_org_dellroad_jc_cgen_analysis_ActiveUseAnalysis$method$copy$0585c1f937996187(_jc_env *, struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseAnalysis$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_org_dellroad_jc_cgen_analysis_ActiveUseAnalysis$method$entryInitialFlow$8b63b3b8f54d43fb(_jc_env *, struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseAnalysis$object *) _JC_JCNI_ATTR;
extern void _jc_org_dellroad_jc_cgen_analysis_ActiveUseAnalysis$method$flowThrough$087b926607d6a11b(_jc_env *, struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseAnalysis$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern jboolean _jc_org_dellroad_jc_cgen_analysis_ActiveUseAnalysis$method$isCheckNeeded$5e337b96839b50c8(_jc_env *, struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseAnalysis$object *, struct _jc_object *, struct _jc_soot_SootClass$object *) _JC_JCNI_ATTR;
extern void _jc_org_dellroad_jc_cgen_analysis_ActiveUseAnalysis$method$merge$37b91166a64cb493(_jc_env *, struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseAnalysis$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_org_dellroad_jc_cgen_analysis_ActiveUseAnalysis$method$newInitialFlow$8126aa62e2c0e28e(_jc_env *, struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseAnalysis$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_org_dellroad_jc_cgen_analysis_ActiveUseAnalysis$method_info$addTransitive$887aecff33247547;
extern _jc_method _jc_org_dellroad_jc_cgen_analysis_ActiveUseAnalysis$method_info$copy$0585c1f937996187;
extern _jc_method _jc_org_dellroad_jc_cgen_analysis_ActiveUseAnalysis$method_info$entryInitialFlow$8b63b3b8f54d43fb;
extern _jc_method _jc_org_dellroad_jc_cgen_analysis_ActiveUseAnalysis$method_info$flowThrough$087b926607d6a11b;
extern _jc_method _jc_org_dellroad_jc_cgen_analysis_ActiveUseAnalysis$method_info$isCheckNeeded$5e337b96839b50c8;
extern _jc_method _jc_org_dellroad_jc_cgen_analysis_ActiveUseAnalysis$method_info$merge$37b91166a64cb493;
extern _jc_method _jc_org_dellroad_jc_cgen_analysis_ActiveUseAnalysis$method_info$newInitialFlow$8126aa62e2c0e28e;

// Virtual methods structure
struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseAnalysis$vmethods {
	void	(*addTransitive$887aecff33247547)(_jc_env *, struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseAnalysis$object *, struct _jc_object *, struct _jc_soot_SootClass$object *) _JC_JCNI_ATTR;
	void	(*copy$0585c1f937996187)(_jc_env *, struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseAnalysis$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*entryInitialFlow$8b63b3b8f54d43fb)(_jc_env *, struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseAnalysis$object *) _JC_JCNI_ATTR;
	void	(*flowThrough$087b926607d6a11b)(_jc_env *, struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseAnalysis$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	jboolean	(*isCheckNeeded$5e337b96839b50c8)(_jc_env *, struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseAnalysis$object *, struct _jc_object *, struct _jc_soot_SootClass$object *) _JC_JCNI_ATTR;
	void	(*merge$37b91166a64cb493)(_jc_env *, struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseAnalysis$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*newInitialFlow$8126aa62e2c0e28e)(_jc_env *, struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseAnalysis$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseAnalysis$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_toolkits_scalar_AbstractFlowAnalysis$vmethods	soot_toolkits_scalar_AbstractFlowAnalysis;
	_jc_soot_toolkits_scalar_FlowAnalysis$vmethods	soot_toolkits_scalar_FlowAnalysis;
	_jc_soot_toolkits_scalar_ForwardFlowAnalysis$vmethods	soot_toolkits_scalar_ForwardFlowAnalysis;
	_jc_org_dellroad_jc_cgen_analysis_ActiveUseAnalysis$vmethods	org_dellroad_jc_cgen_analysis_ActiveUseAnalysis;
};

// Vtype
struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseAnalysis$vtype {
	_jc_type			type;
	_jc_org_dellroad_jc_cgen_analysis_ActiveUseAnalysis$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseAnalysis$sub_refs {
	struct _jc_soot_toolkits_graph_UnitGraph$object	*graph;
};

// Reference instance fields (object)
struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseAnalysis$refs {
    _jc_org_dellroad_jc_cgen_analysis_ActiveUseAnalysis$sub_refs	org_dellroad_jc_cgen_analysis_ActiveUseAnalysis;
    _jc_soot_toolkits_scalar_ForwardFlowAnalysis$sub_refs	soot_toolkits_scalar_ForwardFlowAnalysis;
    _jc_soot_toolkits_scalar_FlowAnalysis$sub_refs	soot_toolkits_scalar_FlowAnalysis;
    _jc_soot_toolkits_scalar_AbstractFlowAnalysis$sub_refs	soot_toolkits_scalar_AbstractFlowAnalysis;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseAnalysis$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseAnalysis$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_toolkits_scalar_AbstractFlowAnalysis$sub_nonrefs	soot_toolkits_scalar_AbstractFlowAnalysis;
    _jc_soot_toolkits_scalar_FlowAnalysis$sub_nonrefs	soot_toolkits_scalar_FlowAnalysis;
    _jc_soot_toolkits_scalar_ForwardFlowAnalysis$sub_nonrefs	soot_toolkits_scalar_ForwardFlowAnalysis;
    _jc_org_dellroad_jc_cgen_analysis_ActiveUseAnalysis$sub_nonrefs	org_dellroad_jc_cgen_analysis_ActiveUseAnalysis;
};

// Object instance structure
struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseAnalysis$object {
	_jc_org_dellroad_jc_cgen_analysis_ActiveUseAnalysis$refs	refs[0];
	_jc_word		lockword;
	_jc_org_dellroad_jc_cgen_analysis_ActiveUseAnalysis$vtype	*vtype;
	_jc_org_dellroad_jc_cgen_analysis_ActiveUseAnalysis$nonrefs	nonrefs;
};

// Type structure
extern _jc_org_dellroad_jc_cgen_analysis_ActiveUseAnalysis$vtype _jc_org_dellroad_jc_cgen_analysis_ActiveUseAnalysis$type;

// Array types class info structures
_JC_DECL_ARRAYS(org_dellroad_jc_cgen_analysis_ActiveUseAnalysis, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_org_dellroad_jc_cgen_analysis_ActiveUseAnalysis$class_object;

#endif	/* _JC_org_dellroad_jc_cgen_analysis_ActiveUseAnalysis_H_ */
